Module: Minimapper

Defined in:
lib/minimapper/mapper/has_many_association.rb,
lib/minimapper/extras.rb,
lib/minimapper/extras/version.rb,
lib/minimapper/entity/has_many.rb,
lib/minimapper/entity/belongs_to.rb,
lib/minimapper/entity/serialized_association.rb

Overview

Mapping of associated entity changes. Creates when not persisted, updates when persisted and removes when it has been removed from the in-memory model.

It assumes there isn’t many associated entities and that find will load associated entities.

Defined Under Namespace

Modules: Entity, Extras, Mapper